pub struct RequestConfig {
pub url: String,
pub method: HttpMethod,
pub headers: HashMap<String, String>,
pub body: Option<Bytes>,
}Expand description
Configuration for a single HTTP request.
Used by custom request generator functions to specify the details of each request.
When using BenchmarkBuilder::request_fn,
your function returns this struct to configure each individual request.
Examples
use httpress::{RequestConfig, HttpMethod};
use std::collections::HashMap;
use bytes::Bytes;
let config = RequestConfig {
url: "http://localhost:3000/api/users".to_string(),
method: HttpMethod::Post,
headers: HashMap::from([
("Content-Type".to_string(), "application/json".to_string()),
("Authorization".to_string(), "Bearer token123".to_string()),
]),
body: Some(Bytes::from(r#"{"name": "John"}"#)),
};Fields
url: StringThe target URL for this request.
method: HttpMethodThe HTTP method to use.
headers: HashMap<String, String>HTTP headers to include in the request.
body: Option<Bytes>Optional request body.